pub enum Commands {
Create {
ami_id: String,
},
List,
Delete {
wait: bool,
},
Start,
Stop {
wait: bool,
},
Upload {
src: Option<String>,
dst: Option<String>,
user: String,
},
Run {
user: String,
command: Vec<String>,
},
Shell {
user: String,
},
Obliterate,
}Variants
Create
Create new instance, and print out host.
If not machine_type is specified, allow user to choose machine_type from list of options.
List
List all instances created by this tool, which is under the same tag.
Delete
Delete 1 or more instances, where all options are displayed using a multi-select input.
Start
Start 1 or more instances.
Starting a stopped instance without an EIP will result in a new IP being assigned.
Stop
Stop 1 or more instances.
Upload
Upload local file(s) or directory to remote target instance directory.
Uses SFTP that rides on top of SSH to transfer files.
Fields
src: Option<String>Local relative/absolute path to file(s) or directory.
If no src is specified, then files within with current
working directory will be uploaded to $HOME of remote.
dst: Option<String>Destination folder path on remote instance to upload files to.
Destination folder(s) must exist, otherwise you have to manually
create them using the run subcommand.
If no dst is specified, files will be uploaded the $HOME/root directory of remote. Root folder will be auto-created.
Run
Executes a given command on remote instance. Warn: output is not printed on centos distro (there may be more).
Only run commands that are non-blocking. Commands like
opening vi does not working at the moment.
TODO: run cmd from target directory.
Shell
SSH into instance.
Executes default bash shell.
Obliterate
Terminate all resources deployed by tool. Does not remove AWS iAM permissions.
Yugi: “I have assembled all the 5 pieces of Exodia. Exodia obliterate!”