pub struct Session { /* private fields */ }Implementations
Sourceimpl Session
impl Session
Sourcepub async fn channel_open_session(&self) -> Result<Channel<Msg>, Error>
pub async fn channel_open_session(&self) -> Result<Channel<Msg>, Error>
Returns reusable remote channel that can used as a SSH/SFTP tunnel.
This prevents direct access to private session.
Sourcepub fn load_secret_key<P: AsRef<Path>>(
secret_: P,
password: Option<&str>,
) -> Result<KeyPair, Error>
pub fn load_secret_key<P: AsRef<Path>>( secret_: P, password: Option<&str>, ) -> Result<KeyPair, Error>
Load a secret key, deciphering it with the supplied password if necessary.
Sourcepub async fn connect(
user: &str,
public_dns_name: String,
ssh_key: String,
) -> Result<Self>
pub async fn connect( user: &str, public_dns_name: String, ssh_key: String, ) -> Result<Self>
Connect to remote instance via SSH.
The public DNS name is the emphemeral host address generated when an EC2 instance starts.
Sourcepub async fn upload(
&self,
src: Option<String>,
dst: Option<String>,
) -> Result<()>
pub async fn upload( &self, src: Option<String>, dst: Option<String>, ) -> Result<()>
Upload files within src to dst directory using SFTP.
If dst is not specified, files will uploaded to $HOME/{cwd}.
The {cwd} folder will be created by default in this use case.
Panics if dst is not a directory.