Module util

Module util 

IO Utilities wrapper to allow automock for requests and user input prompts.

Structs

ScenarioImage
Image doesn’t impl Display, which is necessary for inquire to use it in a Select. This wraps Image and provides a Display impl.
SelectOption
UtilImpl

Functions

biject_paths
calc_prefix
ids_to_str
Express list of instance ids as a comma separated string.
multi_select_instances
select_instance