IO Utilities wrapper to allow automock for requests and user input prompts.
Structs
- Scenario
Image - Image doesn’t impl Display, which is necessary for inquire to use it in a Select. This wraps Image and provides a Display impl.
- Select
Option - Util
Impl
Functions
- biject_
paths - calc_
prefix - ids_
to_ str - Express list of instance ids as a comma separated string.
- multi_
select_ instances - select_
instance